==> cookiepro_plus-1.0.6.tar.gz: cookiepro_plus/src/EventSubscriber/ConfigSaveEventSubscriber.php <==
<?php

namespace Drupal\cookiepro_plus\EventSubscriber;

use Drupal\cookiepro_plus\CookieProInterface;
use Drupal\Core\Config\ConfigCrudEvent;
use Drupal\Core\Config\ConfigEvents;
use Drupal\Core\Menu\LocalTaskManagerInterface;
use Drupal\Core\Routing\RouteBuilderInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Refresh our config override routes and local tasks.
 */
class ConfigSaveEventSubscriber implements EventSubscriberInterface {

  /**
   * The CookiePro service.
   *
   * @var \Drupal\cookiepro_plus\CookieProInterface
   */
  protected $cookiePro;

  /**
   * A local task manager instance.
   *
   * @var \Drupal\Core\Menu\LocalTaskManagerInterface
   */
  protected $localTaskLinkManager;

  /**
   * The route builder.
   *
   * @var \Drupal\Core\Routing\RouteBuilderInterface
   */
  protected $routeBuilder;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[ConfigEvents::SAVE][] = ['onSave'];
    return $events;
  }

  /**
   * Constructor.
   *
   * @param \Drupal\cookiepro_plus\CookieProInterface $cookiepro
   *   The CookiePro service.
   * @param \Drupal\Core\Menu\LocalTaskManagerInterface $local_task_link_manager
   *   A local task manager instance.
   * @param \Drupal\Core\Routing\RouteBuilderInterface $route_builder
   *   The route builder.
   */
  public function __construct(
    CookieProInterface $cookiepro,
    LocalTaskManagerInterface $local_task_link_manager,
    RouteBuilderInterface $route_builder
  ) {
    $this->cookiePro = $cookiepro;
    $this->localTaskLinkManager = $local_task_link_manager;
    $this->routeBuilder = $route_builder;
  }

  /**
   * Invalidate cache tags when particular system config objects are saved.
   *
   * @param \Drupal\Core\Config\ConfigCrudEvent $event
   *   The Event to process.
   */
  public function onSave(ConfigCrudEvent $event): void {

    $config_name = $event->getConfig()->getName();
    if ($config_name === 'language.negotiation') {

      // Make sure our routes and local tasks, depending on the 'url' value, are
      // added or removed.
      if ($event->isChanged('url')) {
        $this->cookiePro->loadUrlLanguageNegotiationDomains();
        $this->routeBuilder->rebuild();
      }
      $this->localTaskLinkManager->clearCachedDefinitions();
    }
  }

}

==> cookiepro_plus-1.0.8.tar.gz: cookiepro_plus/src/EventSubscriber/ConfigSaveEventSubscriber.php <==
<?php

namespace Drupal\cookiepro_plus\EventSubscriber;

use Drupal\cookiepro_plus\CookieProInterface;
use Drupal\Core\Config\ConfigCrudEvent;
use Drupal\Core\Config\ConfigEvents;
use Drupal\Core\Menu\LocalTaskManagerInterface;
use Drupal\Core\Routing\RouteBuilderInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Refresh our config override routes and local tasks.
 */
class ConfigSaveEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[ConfigEvents::SAVE][] = ['onSave'];
    return $events;
  }

  /**
   * Constructor.
   *
   * @param \Drupal\cookiepro_plus\CookieProInterface $cookiePro
   *   The CookiePro service.
   * @param \Drupal\Core\Menu\LocalTaskManagerInterface $localTaskLinkManager
   *   A local task manager instance.
   * @param \Drupal\Core\Routing\RouteBuilderInterface $routeBuilder
   *   The route builder.
   */
  public function __construct(
    protected CookieProInterface $cookiePro,
    protected LocalTaskManagerInterface $localTaskLinkManager,
    protected RouteBuilderInterface $routeBuilder
  ) {}

  /**
   * Invalidate cache tags when particular system config objects are saved.
   *
   * @param \Drupal\Core\Config\ConfigCrudEvent $event
   *   The Event to process.
   */
  public function onSave(ConfigCrudEvent $event): void {

    $config_name = $event->getConfig()->getName();
    if ($config_name === 'language.negotiation') {

      // Make sure our routes and local tasks, depending on the 'url' value, are
      // added or removed.
      if ($event->isChanged('url')) {
        $this->cookiePro->loadUrlLanguageNegotiationDomains();
        $this->routeBuilder->rebuild();
      }
      $this->localTaskLinkManager->clearCachedDefinitions();
    }
  }

}
